//////////////////////////////////////////////////////////////////////////
//
//  File: EgMac.cpp
//  Created: 2007.10.3
//  
//  Author: Erik Brown
//  Principle Investigator: Anthony Hornof
//  Cognitive Modeling and Eye Tracking Lab
//  CIS Department
//  University of Oregon
//  
//  Description:  Provides the platform specific features of a
//                connection to an LC Technologies eye tracking
//                server. Not much here, and there shouldn't be.
//                Mostly member functions that wrap up a line or two
//                of platform specific code. Allows the main
//                application to use an EgBase pointer regardless
//                whether it points to an EgMac or EgWin object.
//
//                See also EgMac.h.
//
//  Copyright (c) 2007 by the University of Oregon.
//  ALL RIGHTS RESERVED.
//
//  Permission to use, copy, and distribute this software in
//  its entirety for non-commercial purposes and without fee,
//  is hereby granted, provided that the above copyright notice
//  and this permission notice appear in all copies and their
//  documentation.
//
//  Software developers, consultants, or anyone else who wishes
//  to use all or part of the software or its documentation for
//  commercial purposes should contact the Technology Transfer
//  Office at the University of Oregon to arrange a commercial
//  license agreement.
//
//  This software is provided "as is" without expressed or
//  implied warranty of any kind.
//
//////////////////////////////////////////////////////////////////////////

#include "EgMac.h"

EgMac::EgMac() :
	EgBase()
{
	// Must initialize the mutex. Do so now even though we're
	// not even connected.
	pthread_mutex_init(&egDataMutex, NULL);

	return;
}

EgMac::~EgMac()
{
	// Shutdown connection with the server.
	disconnect();

	// No longer need the mutex.
	pthread_mutex_destroy(&egDataMutex);

	return;
}

void EgMac::WaitMutex()
{
	pthread_mutex_lock(&egDataMutex);
}

void EgMac::SignalMutex()
{
	pthread_mutex_unlock(&egDataMutex);
}

int EgMac::readSocket(char *buffer, int readBytes)
{
	return read(theSocket, buffer, readBytes);
}

void EgMac::writeSocket(const char *buffer, int len)
{
	write(theSocket, buffer, len);
}

void EgMac::closeSocket()
{
	close(theSocket);
}

void EgMac::startThread()
{
	pthread_create(&readThread, NULL, EyeTrackerReceive, (void*)this);
}

void EgMac::Sleep(unsigned long milliseconds)
{
   ::usleep(milliseconds);
}


