//////////////////////////////////////////////////////////////////////////
//
//  File: EgWin.cpp
//  Created: 2007.10.3
//  
//  Author: Erik Brown
//  Principle Investigator: Anthony Hornof
//  Cognitive Modeling and Eye Tracking Lab
//  CIS Department
//  University of Oregon
//  
//  Description:  Provides the platform specific features of a
//                connection to an LC Technologies eye tracking
//                server. Not much here, and there shouldn't be.
//                Mostly member functions that wrap up a line or two
//                of platform specific code. Allows the main
//                application to use an EgBase pointer regardless
//                whether it points to an EgMac or EgWin object.
//
//                See also EgWin.h.
//
//  Copyright (c) 2001 by the University of Oregon.
//  ALL RIGHTS RESERVED.
//
//  Permission to use, copy, and distribute this software in
//  its entirety for non-commercial purposes and without fee,
//  is hereby granted, provided that the above copyright notice
//  and this permission notice appear in all copies and their
//  documentation.
//
//  Software developers, consultants, or anyone else who wishes
//  to use all or part of the software or its documentation for
//  commercial purposes should contact the Technology Transfer
//  Office at the University of Oregon to arrange a commercial
//  license agreement.
//
//  This software is provided "as is" without expressed or
//  implied warranty of any kind.
//
//////////////////////////////////////////////////////////////////////////

#include <windows.h>

#include "EgWin.h"

EgWin::EgWin()
{
	WORD versionRequested = MAKEWORD(2, 2);
	WSAData wsadata;

   // Needs to be called before any socket stuff can happen.
	WSAStartup(versionRequested, &wsadata);

   // Needs to be initialized. Do so now, even though we aren't
   // connecting yet.
	hMutex = CreateMutex(NULL, false, "dequeMutex");

	return;
}

EgWin::~EgWin()
{
   // Shutdown the connection properly.
   disconnect();

   // Release and cleanup.
	CloseHandle(hMutex);
	WSACleanup();

	return;
}

void EgWin::WaitMutex()
{
	DWORD waitResult = WaitForSingleObject(hMutex, INFINITE);
}

void EgWin::SignalMutex()
{
	ReleaseMutex(hMutex);
}

void EgWin::startThread()
{
	CreateThread(NULL, 0, EyeTrackerReceive, (void*)this, 0, &readThread);
}

void EgWin::writeSocket(const char *buffer, int len)
{
	send(theSocket, buffer, len, 0);
}

int EgWin::readSocket(char *buffer, int bytesToRead)
{
	return recv(theSocket, buffer, bytesToRead, 0);
}

void EgWin::closeSocket()
{
	closesocket(theSocket);
}

void EgWin::Sleep(unsigned long milliseconds)
{
	::Sleep(milliseconds);
}

