//////////////////////////////////////////////////////////////////////////
//
//  File: EgWin.h
//  Created: 2007.10.3
//  
//  Author: Erik Brown
//  Principle Investigator: Anthony Hornof
//  Cognitive Modeling and Eye Tracking Lab
//  CIS Department
//  University of Oregon
//  
//  Description: This is a derived class of EgBase. EgBase and its
//  derivatives, EgMac and EgWin, provide a connection to an LC
//  Technologies eye tracking system. The derived classes provide
//  only what is platform specific to the EgBase object. Things like
//  creating the thread in which we read from the socket, reading
//  and writing with a socket, mutexes, etc. These platform specific
//  pieces are wrapped up as interface methods so that a derived
//  class must implement them (i.e. pure virtual in C++), and a
//  derived object, through a base class pointer, calls these
//  wrappers regardless which kind of object it is. The intention is
//  for there to be very little code here.
//
//  Copyright (c) 2001 by the University of Oregon.
//  ALL RIGHTS RESERVED.
//
//  Permission to use, copy, and distribute this software in
//  its entirety for non-commercial purposes and without fee,
//  is hereby granted, provided that the above copyright notice
//  and this permission notice appear in all copies and their
//  documentation.
//
//  Software developers, consultants, or anyone else who wishes
//  to use all or part of the software or its documentation for
//  commercial purposes should contact the Technology Transfer
//  Office at the University of Oregon to arrange a commercial
//  license agreement.
//
//  This software is provided "as is" without expressed or
//  implied warranty of any kind.
//
//////////////////////////////////////////////////////////////////////////

#ifndef EGWIN_H
#define EGWIN_H

#include "EgBase.h"

class EgWin : public EgBase
{
public:
	EgWin();
	virtual ~EgWin();

   // Needs to be public since it is called by the read thread,
   // which is not part of the class.
	int readSocket(char *buffer, int bytesToRead);

private:
   // Until proven necessary.
   EgWin(const EgWin &source);
   EgWin& operator=(const EgWin &source);

   // Platform specific member variables and interface methods.
	DWORD    readThread;
	HANDLE   hMutex;

	void writeSocket(const char *buffer, int len);

	void startThread();
	void closeSocket();
	void Sleep(unsigned long milliseconds);

	void WaitMutex();
	void SignalMutex();
};

#endif // EGWIN_H
