#!/bin/sh

srcdir=$HOME/src
externalsdir='max-externals.release'
externalsproj='max-externals.xcodeproj'
externalsconfig='Release'
externalseyedata='eyedata'
externalsfixation='fixation'

destname=CMET_MaxMSPExternals
destdir=$HOME/Desktop/$destname

# Remove a previous release package
if [ -d $destdir ]; then
   rm -rf $destdir
fi
mkdir $destdir

# Remove a previous release package
if [ -f $zipfile.gz ]; then
   rm -f $zipfile.gz
fi

# Remove a previous release build.
cd $srcdir
if [ -d $externalsdir ]; then
   rm -rf $externalsdir
fi


mkdir -p $srcdir

# You will likely change the user here.
user=erikb
cvs -d:ext:$user@cs.uoregon.edu:/research/hornof/CVS export -r HEAD -d $externalsdir max-externals

cd $externalsdir

# Copy the code first
ditto . $destdir/Source


# Now build
xcodebuild SYMROOT=. -project $externalsproj -alltargets -configuration $externalsconfig build

if [ $? -gt 0 ]; then
   echo "Build failed with error code $?"
   exit 1;
fi


ditto $externalseyedata/$externalsconfig $destdir
ditto $externalsfixation/$externalsconfig $destdir
ditto $externalseyedata/max-help/*.help $destdir
ditto $externalsfixation/max-help/*.help $destdir

readme=$destdir/README.txt
printf \
 	"Cognitive Modeling and Eye Tracking Laboratory \
 	\nDepartment of Computer and Information Science \
 	\nUniversity of Oregon, Eugene, OR \
 	\n \
	\nPrinciple Investigator: Anthony Hornof \
 	\n
	\nCopyright  2007 by the University of Oregon. \
 	\nALL RIGHTS RESERVED. \
 	\n \
 	\n \
 	\nPermission to use, copy, and distribute this software in \
 	\nits entirety for non-commercial purposes and without fee, \
 	\nis hereby granted, provided that the above copyright notice \
 	\nand this permission notice appear in all copies and their \
 	\ndocumentation. \
 	\n \
 	\nSoftware developers, consultants, or anyone else who wishes \
 	\nto use all or part of the software or its documentation for \
 	\ncommercial purposes should contact the Technology Transfer \
 	\nOffice at the University of Oregon to arrange a commercial \
 	\nlicense agreement. \
 	\n \
 	\nThis software is provided \"as is\" without expressed or \
 	\nimplied warranty of any kind." \
	> $readme

cd $destdir/..
tar -czf $destdir.tar.gz $destname

exit 0



